@@ -40,6 +40,7 @@ from neutron_lib.api.definitions import l3_flavors
 from neutron_lib.api.definitions import logging
 from neutron_lib.api.definitions import logging_resource
 from neutron_lib.api.definitions import metering
+from neutron_lib.api.definitions import multiprovidernet
 from neutron_lib.api.definitions import network
 from neutron_lib.api.definitions import network_availability_zone
 from neutron_lib.api.definitions import network_ip_availability
@@ -53,13 +54,16 @@ from neutron_lib.api.definitions import portbindings_extended
 from neutron_lib.api.definitions import project_id
 from neutron_lib.api.definitions import provider_net
 from neutron_lib.api.definitions import qos
+from neutron_lib.api.definitions import qos_default
 from neutron_lib.api.definitions import router_availability_zone
 from neutron_lib.api.definitions import router_interface_fip
+from neutron_lib.api.definitions import servicetype
 from neutron_lib.api.definitions import subnet
 from neutron_lib.api.definitions import subnet_onboard
 from neutron_lib.api.definitions import subnetpool
 from neutron_lib.api.definitions import trunk
 from neutron_lib.api.definitions import trunk_details
+from neutron_lib.api.definitions import vlantransparent
 
 
 _ALL_API_DEFINITIONS = {
@@ -93,6 +97,7 @@ _ALL_API_DEFINITIONS = {
     logging,
     logging_resource,
     metering,
+    multiprovidernet,
     network,
     network_availability_zone,
     network_ip_availability,
@@ -106,11 +111,14 @@ _ALL_API_DEFINITIONS = {
     project_id,
     provider_net,
     qos,
+    qos_default,
     router_availability_zone,
     router_interface_fip,
+    servicetype,
     subnet,
     subnet_onboard,
     subnetpool,
     trunk,
-    trunk_details
+    trunk_details,
+    vlantransparent
 }
