@@ -17,8 +17,10 @@ NETWORK = 'network'
 NETWORKS = 'networks'
 PORT = 'port'
 PORTS = 'ports'
+PORT_BINDING = 'port_binding'
 PORT_DEVICE = 'port_device'
 PROCESS = 'process'
+RBAC_POLICY = 'rbac-policy'
 ROUTER = 'router'
 ROUTER_GATEWAY = 'router_gateway'
 ROUTER_INTERFACE = 'router_interface'
