@@ -133,6 +133,7 @@ PROTO_NAME_ESP = 'esp'
 PROTO_NAME_GRE = 'gre'
 PROTO_NAME_ICMP = 'icmp'
 PROTO_NAME_IGMP = 'igmp'
+PROTO_NAME_IPIP = 'ipip'
 PROTO_NAME_IPV6_ENCAP = 'ipv6-encap'
 PROTO_NAME_IPV6_FRAG = 'ipv6-frag'
 PROTO_NAME_IPV6_ICMP = 'ipv6-icmp'
@@ -158,6 +159,7 @@ PROTO_NUM_ESP = 50
 PROTO_NUM_GRE = 47
 PROTO_NUM_ICMP = 1
 PROTO_NUM_IGMP = 2
+PROTO_NUM_IPIP = 4
 PROTO_NUM_IPV6_ENCAP = 41
 PROTO_NUM_IPV6_FRAG = 44
 PROTO_NUM_IPV6_ICMP = 58
@@ -180,6 +182,7 @@ IP_PROTOCOL_MAP = {PROTO_NAME_AH: PROTO_NUM_AH,
                    PROTO_NAME_GRE: PROTO_NUM_GRE,
                    PROTO_NAME_ICMP: PROTO_NUM_ICMP,
                    PROTO_NAME_IGMP: PROTO_NUM_IGMP,
+                   PROTO_NAME_IPIP: PROTO_NUM_IPIP,
                    PROTO_NAME_IPV6_ENCAP: PROTO_NUM_IPV6_ENCAP,
                    PROTO_NAME_IPV6_FRAG: PROTO_NUM_IPV6_FRAG,
                    PROTO_NAME_IPV6_ICMP: PROTO_NUM_IPV6_ICMP,
